"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const src_1 = require("../../src");
const validator = src_1.validatorBuilder()
    .newRule()
    .withField('webpushVapidPublicKey')
    .validate(src_1.RuleBuilder.matches('^[A-Za-z0-9_-]*$'))
    .withField('webpushVapidPrivateKey')
    .validate(src_1.RuleBuilder.isRequiredBy.withParent('webpushVapidPublicKey').build())
    .validate(src_1.RuleBuilder.matches('^[A-Za-z0-9_-]*$'))
    .withField('webpushAlias')
    .validate(src_1.RuleBuilder.required()
    .withErrorMessage('Please enter a valid URL or mailto address')
    .build())
    .validate(src_1.RuleBuilder.composite
    .any()
    .withSubRule(src_1.RuleBuilder.matches('^mailto: ?(?:[a-z0-9!#$%&\'*+\\/=?^_`{|}~-]+(?:\\.[a-z0-9!#$%&\'*+\\/=?^_`{|}~-]+)*|"(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21\x23-\x5b\x5d-\x7f]|\\\\[\x01-\x09\x0b\x0c\x0e-\x7f])*")@(?:(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\\[(?:(?:(2(5[0-5]|[0-4][0-9])|1[0-9][0-9]|[1-9]?[0-9]))\\.){3}(?:(2(5[0-5]|[0-4][0-9])|1[0-9][0-9]|[1-9]?[0-9])|[a-z0-9-]*[a-z0-9]:(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21-\x5a\x53-\x7f]|\\\\[\x01-\x09\x0b\x0c\x0e-\x7f])+)\\])$'))
    .withSubRule(src_1.RuleBuilder.isValidUrl()
    .requireTld(true)
    .requireHost(true)
    .requireProtocol(true)
    .build())
    .build('Please enter a valid URL or mailto address'))
    .build();
describe('RequiredBy Validator Builder', () => {
    it('Only name and alias', () => {
        utils_1.testValidator(validator, {
            valid: [{ name: 'test', webpushAlias: 'mailto:mziccard@redhat.com' }],
            invalid: [{ name: 'test' }],
        });
    });
    it('Only name and alias and public key', () => {
        utils_1.testValidator(validator, {
            valid: [
                {
                    name: 'test',
                    webpushAlias: 'mailto:mziccard@redhat.com',
                    webpushVapidPublicKey: 'aaa',
                    webpushVapidPrivateKey: 'aaa',
                },
            ],
            invalid: [
                {
                    name: 'test',
                    webpushAlias: 'mailto:mziccard@redhat.com',
                    webpushVapidPublicKey: 'aaa',
                },
            ],
        });
    });
});
//# sourceMappingURL=RequiredBy.test.js.map